@@ -54,6 +54,16 @@ def _get_default_index_registry() -> IndexRegistry:
     return index_registry
 
 
+def _safe_get_index_struct(
+    docstore: DocumentStore, index_struct_id: str
+) -> IndexStruct:
+    """Try get index struct."""
+    index_struct = docstore.get_document(index_struct_id)
+    if not isinstance(index_struct, IndexStruct):
+        raise ValueError("Invalid `index_struct_id` - must be an IndexStruct")
+    return index_struct
+
+
 class ComposableGraph:
     """Composable graph."""
 
@@ -95,7 +105,7 @@ class ComposableGraph:
     def query(
         self,
         query_str: str,
-        query_configs: Optional[List[QUERY_CONFIG_TYPE]],
+        query_configs: Optional[List[QUERY_CONFIG_TYPE]] = None,
         verbose: bool = False,
     ) -> Response:
         """Query the index."""
@@ -112,6 +122,43 @@ class ComposableGraph:
         )
         return query_runner.query(query_str, self._index_struct)
 
+    def get_index(
+        self, index_struct_id: str, index_cls: Type[BaseGPTIndex], **kwargs: Any
+    ) -> BaseGPTIndex:
+        """Get index."""
+        index_struct = _safe_get_index_struct(self._docstore, index_struct_id)
+        return index_cls(
+            index_struct=index_struct,
+            docstore=self._docstore,
+            index_registry=self._index_registry,
+            **kwargs
+        )
+
+    @classmethod
+    def load_from_string(cls, index_string: str, **kwargs: Any) -> "ComposableGraph":
+        """Load index from string (in JSON-format).
+
+        This method loads the index from a JSON string. The index data
+        structure itself is preserved completely. If the index is defined over
+        subindices, those subindices will also be preserved (and subindices of
+        those subindices, etc.).
+
+        Args:
+            save_path (str): The save_path of the file.
+
+        Returns:
+            BaseGPTIndex: The loaded index.
+
+        """
+        result_dict = json.loads(index_string)
+        # TODO: this is hardcoded for now, allow it to be specified by the user
+        index_registry = _get_default_index_registry()
+        docstore = DocumentStore.load_from_dict(
+            result_dict["docstore"], index_registry.type_to_struct
+        )
+        index_struct = _safe_get_index_struct(docstore, result_dict["index_struct_id"])
+        return cls(docstore, index_registry, index_struct, **kwargs)
+
     @classmethod
     def load_from_disk(cls, save_path: str, **kwargs: Any) -> "ComposableGraph":
         """Load index from disk.
@@ -129,19 +176,11 @@ class ComposableGraph:
 
         """
         with open(save_path, "r") as f:
-            result_dict = json.load(f)
-            # TODO: this is hardcoded for now, allow it to be specified by the user
-            index_registry = _get_default_index_registry()
-            docstore = DocumentStore.load_from_dict(
-                result_dict["docstore"], index_registry.type_to_struct
-            )
-            index_struct = docstore.get_document(result_dict["index_struct_id"])
-            if not isinstance(index_struct, IndexStruct):
-                raise ValueError("Invalid `index_struct_id` - must be an IndexStruct")
-            return cls(docstore, index_registry, index_struct, **kwargs)
+            file_contents = f.read()
+            return cls.load_from_string(file_contents, **kwargs)
 
-    def save_to_disk(self, save_path: str, **save_kwargs: Any) -> None:
-        """Save to file.
+    def save_to_string(self, **save_kwargs: Any) -> str:
+        """Save to string.
 
         This method stores the index into a JSON file stored on disk.
 
@@ -153,5 +192,17 @@ class ComposableGraph:
             "index_struct_id": self._index_struct.get_doc_id(),
             "docstore": self._docstore.serialize_to_dict(),
         }
+        return json.dumps(out_dict)
+
+    def save_to_disk(self, save_path: str, **save_kwargs: Any) -> None:
+        """Save to file.
+
+        This method stores the index into a JSON file stored on disk.
+
+        Args:
+            save_path (str): The save_path of the file.
+
+        """
+        index_string = self.save_to_string(**save_kwargs)
         with open(save_path, "w") as f:
-            json.dump(out_dict, f)
+            f.write(index_string)
