@@ -62,7 +62,8 @@ class Node(IndexStruct):
         )
         return result_text
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         # TODO: consolidate with IndexStructType
         return "node"
@@ -100,7 +101,8 @@ class IndexGraph(IndexStruct):
 
         self.all_nodes[node.index] = node
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         return "tree"
 
@@ -147,7 +149,8 @@ class KeywordTable(IndexStruct):
         """Get the size of the table."""
         return len(self.table)
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         return "keyword_table"
 
@@ -163,7 +166,8 @@ class IndexList(IndexStruct):
         # don't worry about child indices for now, nodes are all in order
         self.nodes.append(node)
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         return "list"
 
@@ -212,7 +216,8 @@ class BaseIndexDict(IndexStruct):
         """Get node."""
         return self.get_nodes([text_id])[0]
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         return "dict"
 
@@ -226,7 +231,8 @@ class IndexDict(BaseIndexDict):
 
     """
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         return "dict"
 
@@ -250,7 +256,8 @@ class SimpleIndexDict(BaseIndexDict):
             raise ValueError("text_id must be a string.")
         self.embedding_dict[text_id] = embedding
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         return "simple_dict"
 
@@ -277,7 +284,8 @@ class WeaviateIndexStruct(IndexStruct):
             raise ValueError("class_prefix must be provided.")
         return self.class_prefix
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         return "weaviate"
 
@@ -290,6 +298,35 @@ class PineconeIndexStruct(IndexStruct):
 
     """
 
-    def get_type(self) -> str:
+    @classmethod
+    def get_type(cls) -> str:
         """Get type."""
         return "pinecone"
+
+
+@dataclass
+class QdrantIndexStruct(IndexStruct):
+    """And index struct for Qdrant.
+
+    Docs are stored in Qdrant directly.
+    This index struct helps to store the collection name
+
+    """
+
+    collection_name: Optional[str] = None
+
+    def __post_init__(self) -> None:
+        """Post init."""
+        if self.collection_name is None:
+            raise ValueError("collection_name must be provided.")
+
+    def get_collection_name(self) -> str:
+        """Get class prefix."""
+        if self.collection_name is None:
+            raise ValueError("collection_name must be provided.")
+        return self.collection_name
+
+    @classmethod
+    def get_type(cls) -> str:
+        """Get type."""
+        return "qdrant"
