@@ -93,6 +93,10 @@ class BaseGPTIndex(Generic[IS]):
         self._index_registry = index_registry or IndexRegistry()
 
         if index_struct is not None:
+            if not isinstance(index_struct, self.index_struct_cls):
+                raise ValueError(
+                    f"index_struct must be of type {self.index_struct_cls}"
+                )
             self._index_struct = index_struct
         else:
             documents = cast(Sequence[DOCUMENTS_INPUT], documents)
@@ -230,7 +234,11 @@ class BaseGPTIndex(Generic[IS]):
         If you wish to delete the index struct, you can use this doc_id.
 
         """
+        old_doc_id = self._index_struct.get_doc_id()
         self._index_struct.doc_id = doc_id
+        # Note: we also need to delete old doc_id, and update docstore
+        self._docstore.delete_document(old_doc_id)
+        self._docstore.add_documents([self._index_struct])
 
     def get_doc_id(self) -> str:
         """Get doc_id for index struct.
@@ -395,6 +403,35 @@ class BaseGPTIndex(Generic[IS]):
     def get_query_map(cls) -> Dict[str, Type[BaseGPTIndexQuery]]:
         """Get query map."""
 
+    @classmethod
+    def load_from_string(cls, index_string: str, **kwargs: Any) -> "BaseGPTIndex":
+        """Load index from string (in JSON-format).
+
+        This method loads the index from a JSON string. The index data
+        structure itself is preserved completely. If the index is defined over
+        subindices, those subindices will also be preserved (and subindices of
+        those subindices, etc.).
+
+        NOTE: load_from_string should not be used for indices composed on top
+        of other indices. Please define a `ComposableGraph` and use
+        `save_to_string` and `load_from_string` on that instead.
+
+        Args:
+            index_string (str): The index string (in JSON-format).
+
+        Returns:
+            BaseGPTIndex: The loaded index.
+
+        """
+        result_dict = json.loads(index_string)
+        index_struct = cls.index_struct_cls.from_dict(result_dict["index_struct"])
+        type_to_struct = {index_struct.get_type(): type(index_struct)}
+        docstore = DocumentStore.load_from_dict(
+            result_dict["docstore"],
+            type_to_struct=type_to_struct,
+        )
+        return cls(index_struct=index_struct, docstore=docstore, **kwargs)
+
     @classmethod
     def load_from_disk(cls, save_path: str, **kwargs: Any) -> "BaseGPTIndex":
         """Load index from disk.
@@ -416,14 +453,35 @@ class BaseGPTIndex(Generic[IS]):
 
         """
         with open(save_path, "r") as f:
-            result_dict = json.load(f)
-            index_struct = cls.index_struct_cls.from_dict(result_dict["index_struct"])
-            type_to_struct = {index_struct.get_type(): type(index_struct)}
-            docstore = DocumentStore.load_from_dict(
-                result_dict["docstore"],
-                type_to_struct=type_to_struct,
+            file_contents = f.read()
+            return cls.load_from_string(file_contents, **kwargs)
+
+    def save_to_string(self, **save_kwargs: Any) -> str:
+        """Save to string.
+
+        This method stores the index into a JSON string.
+
+        NOTE: save_to_string should not be used for indices composed on top
+        of other indices. Please define a `ComposableGraph` and use
+        `save_to_string` and `load_from_string` on that instead.
+
+        Returns:
+            str: The JSON string of the index.
+
+        """
+        if self.docstore.contains_index_struct(
+            exclude_ids=[self.index_struct.get_doc_id()]
+        ):
+            raise ValueError(
+                "Cannot call `save_to_string` on index if index is composed on top of "
+                "other indices. Please define a `ComposableGraph` and use "
+                "`save_to_string` and `load_from_string` on that instead."
             )
-            return cls(index_struct=index_struct, docstore=docstore, **kwargs)
+        out_dict: Dict[str, dict] = {
+            "index_struct": self.index_struct.to_dict(),
+            "docstore": self.docstore.serialize_to_dict(),
+        }
+        return json.dumps(out_dict, **save_kwargs)
 
     def save_to_disk(self, save_path: str, **save_kwargs: Any) -> None:
         """Save to file.
@@ -438,17 +496,6 @@ class BaseGPTIndex(Generic[IS]):
             save_path (str): The save_path of the file.
 
         """
-        if self.docstore.contains_index_struct(
-            exclude_ids=[self.index_struct.get_doc_id()]
-        ):
-            raise ValueError(
-                "Cannot call `save_to_disk` on index if index is composed on top of "
-                "other indices. Please define a `ComposableGraph` and use "
-                "`save_to_disk` and `load_from_disk` on that instead."
-            )
-        out_dict: Dict[str, dict] = {
-            "index_struct": self.index_struct.to_dict(),
-            "docstore": self.docstore.serialize_to_dict(),
-        }
+        index_string = self.save_to_string(**save_kwargs)
         with open(save_path, "w") as f:
-            json.dump(out_dict, f)
+            f.write(index_string)
