@@ -1,8 +1,11 @@
 """Default query for GPTSimpleVectorIndex."""
-from typing import List
+from typing import List, Optional
 
 from gpt_index.data_structs.data_structs import Node, SimpleIndexDict
-from gpt_index.indices.query.embedding_utils import get_top_k_embeddings
+from gpt_index.indices.query.embedding_utils import (
+    SimilarityTracker,
+    get_top_k_embeddings,
+)
 from gpt_index.indices.query.vector_store.base import BaseGPTVectorStoreIndexQuery
 from gpt_index.indices.utils import truncate_text
 
@@ -30,7 +33,10 @@ class GPTSimpleVectorIndexQuery(BaseGPTVectorStoreIndexQuery[SimpleIndexDict]):
     """
 
     def _get_nodes_for_response(
-        self, query_str: str, verbose: bool = False
+        self,
+        query_str: str,
+        verbose: bool = False,
+        similarity_tracker: Optional[SimilarityTracker] = None,
     ) -> List[Node]:
         """Get nodes for response."""
         # TODO: consolidate with get_query_text_embedding_similarities
@@ -39,7 +45,7 @@ class GPTSimpleVectorIndexQuery(BaseGPTVectorStoreIndexQuery[SimpleIndexDict]):
         node_ids = [t[0] for t in items]
         embeddings = [t[1] for t in items]
 
-        _, top_ids = get_top_k_embeddings(
+        top_similarities, top_ids = get_top_k_embeddings(
             self._embed_model,
             query_embedding,
             embeddings,
@@ -47,13 +53,20 @@ class GPTSimpleVectorIndexQuery(BaseGPTVectorStoreIndexQuery[SimpleIndexDict]):
             embedding_ids=node_ids,
         )
         top_k_nodes = self._index_struct.get_nodes(top_ids)
+        if similarity_tracker is not None:
+            for node, similarity in zip(top_k_nodes, top_similarities):
+                similarity_tracker.add(node, similarity)
 
         # print verbose output
         if verbose:
             fmt_txts = []
-            for node_idx, node in zip(top_ids, top_k_nodes):
-                fmt_txt = f"> [Node {node_idx}] {truncate_text(node.get_text(), 100)}"
+            for node_idx, node_similarity, node in zip(
+                top_ids, top_similarities, top_k_nodes
+            ):
+                fmt_txt = f"> [Node {node_idx}] [Similarity score: \
+                    {node_similarity:.6}] {truncate_text(node.get_text(), 100)}"
                 fmt_txts.append(fmt_txt)
             top_k_node_text = "\n".join(fmt_txts)
             print(f"> Top {len(top_k_nodes)} nodes:\n{top_k_node_text}")
+
         return top_k_nodes
