@@ -7,7 +7,7 @@ An index that that is built on top of an existing vector store.
 from abc import abstractmethod
 from typing import Any, Generic, Optional, Sequence, TypeVar
 
-from gpt_index.data_structs.data_structs import BaseIndexDict
+from gpt_index.data_structs.data_structs import IndexStruct
 from gpt_index.embeddings.base import BaseEmbedding
 from gpt_index.indices.base import DOCUMENTS_INPUT, BaseGPTIndex
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
@@ -16,7 +16,7 @@ from gpt_index.prompts.default_prompts import DEFAULT_TEXT_QA_PROMPT
 from gpt_index.prompts.prompts import QuestionAnswerPrompt
 from gpt_index.schema import BaseDocument
 
-BID = TypeVar("BID", bound=BaseIndexDict)
+BID = TypeVar("BID", bound=IndexStruct)
 
 
 class BaseGPTVectorStoreIndex(BaseGPTIndex[BID], Generic[BID]):
