@@ -4,14 +4,16 @@ An index that that is built on top of an existing vector store.
 
 """
 
-from typing import Any, Optional, Sequence, cast
+from typing import Any, Dict, Optional, Sequence, Type, cast
 
 import numpy as np
 
 from gpt_index.data_structs.data_structs import IndexDict
 from gpt_index.embeddings.base import BaseEmbedding
 from gpt_index.indices.base import DOCUMENTS_INPUT, BaseGPTIndex
+from gpt_index.indices.query.base import BaseGPTIndexQuery
 from gpt_index.indices.query.schema import QueryMode
+from gpt_index.indices.query.vector_store.faiss import GPTFaissIndexQuery
 from gpt_index.indices.vector_store.base import BaseGPTVectorStoreIndex
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
@@ -80,6 +82,14 @@ class GPTFaissIndex(BaseGPTVectorStoreIndex[IndexDict]):
             **kwargs,
         )
 
+    @classmethod
+    def get_query_map(self) -> Dict[str, Type[BaseGPTIndexQuery]]:
+        """Get query map."""
+        return {
+            QueryMode.DEFAULT: GPTFaissIndexQuery,
+            QueryMode.EMBEDDING: GPTFaissIndexQuery,
+        }
+
     def _add_document_to_index(
         self,
         index_struct: IndexDict,
