@@ -10,8 +10,12 @@ from gpt_index.readers.schema.base import Document
 class BaseReader:
     """Utilities for loading data from a directory."""
 
+    def __init__(self, verbose: bool = False):
+        """Init params."""
+        self.verbose = verbose
+
     @abstractmethod
-    def load_data(self, **load_kwargs: Any) -> List[Document]:
+    def load_data(self, *args: Any, **load_kwargs: Any) -> List[Document]:
         """Load data from the input directory."""
 
     def load_langchain_documents(self, **load_kwargs: Any) -> List[LCDocument]:
